@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.518";
+our $VERSION = "0.519";
 
 1;
 
@@ -1128,18 +1128,22 @@ Exceptions thrown by L<Sys::Socket#recv|SPVM::Sys::Socket/"recv"> method could b
 
 =head2 recvfrom
 
-C<static method recvfrom : int ($socket_fd : int, $buffer : mutable string, $length : int, $flags : int, $sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $buffer_offset : int = 0);>
+C<static method recvfrom : int ($socket_fd : int, $buffer : mutable string, $length : int, $flags : int, $sockaddr_ref : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>[], $buffer_offset : int = 0);>
 
-Receives a message on a socket given the peer socket address $sockaddr for output.
+Receives a message on a socket given the array $sockaddr_ref for a peer socket address for output.
 
 This method calls L<Sys::Socket#recvfrom|SPVM::Sys::Socket/"recvfrom"> method given the arguments given to this method and returns its return value.
 
-$addrlen is set to the return value of L<Sys::Socket::Sockaddr::Storage#size|SPVM::Sys::Socket::Sockaddr::Storage/"size"> method.
+$addrlen_ref is set to an int reference.
 
-If $sockaddr is given, $sockaddr is upgraded by calling L<Sys::Socket::Sockaddr#upgrade|SPVM::Sys::Socket::Sockaddr/"upgrade"> method.
+If $sockaddr_ref is given, $sockaddr is set to a L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> object.
+
+In this case, $sockaddr is upgraded by calling L<Sys::Socket::Sockaddr#upgrade|SPVM::Sys::Socket::Sockaddr/"upgrade"> method and $sockaddr_ref at index 0 is set to it.
 
 Exceptions:
 
+If $sockaddr_ref for an array for a peer socket address for output is defined, the length must be 1.
+
 Exceptions thrown by L<Sys::Socket#recvfrom|SPVM::Sys::Socket/"recvfrom"> method could be thrown.
 
 =head2 send
